@@ -69,7 +69,7 @@ pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
 // offline cache capacity in kilobytes
-pref("browser.cache.offline.capacity",         10240);
+pref("browser.cache.offline.capacity",         512000);
 
 // offline apps should be limited to this much data in global storage
 // (in kilobytes)
@@ -134,7 +134,7 @@ pref("gfx.color_management.display_profile", "");
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 138 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 138 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -147,7 +147,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 154 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 154 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -169,6 +169,9 @@ pref("accessibility.typeaheadfind.soundURL", "beep");
 pref("accessibility.typeaheadfind.enablesound", true);
 pref("accessibility.typeaheadfind.prefillwithselection", true);
 
+// use Mac OS X Appearance panel text smoothing setting when rendering text, disabled by default
+pref("gfx.use_text_smoothing_setting", false);
+
 pref("browser.history_expire_days", 9);
 
 // loading and rendering of framesets and iframes
@@ -520,7 +523,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 529 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 532 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -605,7 +608,7 @@ pref("network.http.redirection-limit", 20);
 pref("network.http.accept-encoding" ,"gzip,deflate");
 
 pref("network.http.pipelining"      , false);
-pref("network.http.pipelining.ssl"  , true); // enable pipelining over SSL
+pref("network.http.pipelining.ssl"  , false); // disable pipelining over SSL
 pref("network.http.proxy.pipelining", false);
 
 // Max number of requests in the pipeline
@@ -749,7 +752,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 763 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 766 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -773,9 +776,9 @@ pref("network.hosts.nntp_server",           "news.mozilla.org");
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 788 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 791 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 795 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 798 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1109,15 +1112,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1511 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1515 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1910 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1932 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2098 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2129 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2189 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2220 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2192 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2223 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1150,6 +1153,9 @@ pref("autocomplete.ungrab_during_mode_switch", true);
 // toggling to use the XUL filepicker
 pref("ui.allow_platform_file_picker", true);
 
+// should NetworkManager be authoritative for online/offline status?
+pref("toolkit.networkmanager.disable", false);
+
 pref("helpers.global_mime_types_file", "/etc/mime.types");
 pref("helpers.global_mailcap_file", "/etc/mailcap");
 pref("helpers.private_mime_types_file", "~/.mime.types");
@@ -1199,7 +1205,9 @@ pref("font.name.serif.ko", "serif");
 pref("font.name.sans-serif.ko", "sans-serif");
 pref("font.name.monospace.ko", "monospace");
 
-// th
+pref("font.name.serif.th", "serif");
+pref("font.name.sans-serif.th", "sans-serif");
+pref("font.name.monospace.th", "monospace");
 
 pref("font.name.serif.tr", "serif");
 pref("font.name.sans-serif.tr", "sans-serif");
@@ -1263,7 +1271,8 @@ pref("font.size.fixed.ko", 16);
 
 pref("font.default.th", "serif");
 pref("font.size.variable.th", 16);
-pref("font.size.fixed.th", 12);
+pref("font.size.fixed.th", 13);
+pref("font.minimum-size.th", 13);
 
 pref("font.default.tr", "serif");
 pref("font.size.variable.tr", 16);
@@ -1371,15 +1380,15 @@ pref("print.postscript.paper_size",    "letter");
 pref("print.postscript.orientation",   "portrait");
 pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2448 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2485 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2516 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2553 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2542 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2579 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2562 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2599 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2570 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2607 "/builds/tinderbox/Xr-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
